/**
 * Auther : MobifinElite Developer
 * Created : 05-11-2019
 * Language Select Dropdown
 */

/**
 * Initial all package and component required for this component
 * Connect : used for action, reducer & sagas file.
 * $ : used for jquery
 */
import React, { Component, Fragment } from 'react';
import { Input, Label, FormGroup } from 'reactstrap';
import $ from 'jquery';
//  import { setLanguage, rtlLayoutAction, getLanguages } from 'Actions';
//  const { setLocalStorage } = require('DefaultHelpers');

const DynamicLanguageComponent = ({ props = {}, state = {}, languages = [], handleOnChangeEvent = () => ({}), handleOnBlurEvent = () => ({}), handleOnFocusEvent = () => ({}) }) => {
    const {
        options: {
            type = 'radio',
            defaultValue = 'en',
            name: inputName = '',
            isDisabled = false,
            isShowImage = false,
            onBlurURL = '',
            onFocusURL = '',
            onBlurMethod = onBlurURL !== '' ? (e) => handleOnBlurEvent(e) : () => ({}),
            onFocusMethod = onFocusURL !== '' ? (e) => handleOnFocusEvent(e) : () => ({}),
            onChangeMethod = isDisabled ? () => ({}) : ((e) => handleOnChangeEvent(e))
        } = {}
    } = props;
    let locale = {};
    let noOfLanguages = languages.length;
    let lenghtClass = 'col-md-4';
    if (noOfLanguages === 1) {
        lenghtClass = 'col-md-12';
    } else if (noOfLanguages < 3) {
        lenghtClass = 'col-md-6';
    }

    if (type === 'radio') {
        return (
            <div className={`cstm_icn_area show_btn row`}>
                {languages && languages.map((langItem, index) => {
                    const { name: displayLabel = '', locale: langValue = '', icon = '', languageId = '' } = langItem;
                    return (
                        <div className={`col-6 rdo_btn_area ${lenghtClass}`} key={`mlti_rdi_${index}`}>
                            <Label className={`rdo_btn ${noOfLanguages < 3 ? 'm-0' : ''} ${defaultValue === langValue ? 'active' : ''}`} htmlFor={`lang_rdo_${index}`}>
                                {displayLabel}
                            </Label>
                            <Input
                                type="radio"
                                className={`custom-control-input`}
                                name={inputName}
                                id={`lang_rdo_${index}`}
                                value={JSON.stringify(langItem)}
                                disabled={isDisabled}
                                required={false}
                                checked={defaultValue === langValue ? 'checked' : ''}
                                onBlur={onBlurMethod}
                                onFocus={onFocusMethod}
                                onChange={(e) => handleOnChangeEvent(JSON.parse(e.target.value))}
                            />
                        </div>
                    )
                })}
            </div>
        )
    } else if (type === 'drop_down' && isShowImage) {
        var index = languages.findIndex(p => p.locale === locale.locale);
        locale = languages[index];
        return (
            <Input type="select" name="loginLangauge" value={JSON.stringify(locale)} onChange={(e) => handleOnChangeEvent(JSON.parse(e.target.value))}>
                {languages && languages.map((language, index) => (
                    <option value={JSON.stringify(language)} key={`sel_opt_${index}`}>{language.locale}</option>
                ))}
            </Input>
        )
    } else {
        var index = languages.findIndex(p => p.locale === locale.locale);
        locale = languages[index];
        return (
            <Input type="select" name="loginLangauge" value={JSON.stringify(locale)} onChange={(e) => handleOnChangeEvent(JSON.parse(e.target.value))}>
                {languages && languages.map((language, index) => (
                    <option value={JSON.stringify(language)} key={`sel_opt_${index}`}>{language.locale}</option>
                ))}
            </Input>
        )
    }
}

/**
 * Start LanguageProvider class component
 * @props {*Array} languages
 */
class LanguageProvider extends Component {
    constructor(props) {
        super(props)
    }

    // on change language
    handleOnChangeEvent = (e) => {
        const lang = JSON.parse(e.target.value);
        const { locale: value = '' } = lang;
        this.props.onChange(e.target.type, e.target.name, value, e.target.checked)
        this.props.setLanguage(lang);
        localStorage.setItem('userLangPreference', JSON.stringify(lang));

        if (String(lang.rtlLayout) === "true") {
            this.rtlLayoutHanlder(true);
        } else {
            this.rtlLayoutHanlder(false);
        }
    }

    // For GetLanguage Call Action
    componentWillMount() {
        this.props.getLanguages();
    }

    /**
     * Rtl Layout Event Hanlder
     * Use to Enable rtl Layout
     * @param {*object} event
      */
    rtlLayoutHanlder(isTrue) {
        if (isTrue) {
            $("html").attr("dir", "rtl");
        } else {
            $("html").attr("dir", "ltr")
        }
        if (typeof this.props.setLocalStorage === 'function') {
            this.props.setLocalStorage();
        }
        this.props.rtlLayoutAction(isTrue);
    }

    /* Render content here.. */
    render() {
        const { errorMsg, defaultLng, reqData = {}, settings: { languages = [] } = {} } = this.props;
        let { id, key, className, defaultValue = '', label: { locale: { [defaultLng]: labelTitle = '' } = {} } = {}, name, type = 'radio', status, required = true, isDisabled = false, labelAlignment = 'left', multiple, onBlurURL = '', onFocusURL = '', onChangeURL = '', showLink, link } = this.props.optionsObj;
        let dynamicKey = 'frm_file_' + (name !== undefined ? name : 'textFileInput');
        let labelString = labelAlignment !== undefined ? labelAlignment.toString().toLowerCase() : '';
        let classLabel = labelString === 'top-left' || labelString === 'top-right' ? 'col' : 'col';
        let classInput = labelString === 'top-left' || labelString === 'top-right' ? 'col-12' : 'col-md-6 col-sm-12';
        let lableAlign = labelString === 'right' || labelString === 'top-right' ? 'right' : 'left';
        const { [name]: reqDefaultValue = '' } = reqData;
        // defaultValue = defaultValue !== '' ? defaultValue : defaultLng;
        defaultValue = defaultLng;
        if (reqDefaultValue !== '') {
            defaultValue = reqDefaultValue;
        }

        let noOfLanguages = languages.length;
        let lenghtClass = 'col-md-4';
        if (noOfLanguages === 1) {
            lenghtClass = 'col-md-12';
        } else if (noOfLanguages < 3) {
            lenghtClass = 'col-md-6';
        }

        return (
            <Fragment>
                <FormGroup className="row" key={dynamicKey}>
                    {
                        labelString === 'right'
                            ?
                            <Fragment>
                                <div className={`${classInput} ${className}${errorMsg ? ' is_err' : ''}`}>
                                    {/* <DynamicLanguageComponent props={this.props} state={this.state} languages={languages} handleOnChangeEvent={this.handleOnChangeEvent()} /> */}
                                    <div className={`cstm_icn_area show_btn row`}>
                                        {languages && languages.map((langItem, index) => {
                                            const { name: displayLabel = '', locale: langValue = '', icon = '', languageId = '' } = langItem;
                                            return (
                                                <div className={`col-6 rdo_btn_area ${lenghtClass}`} key={`mlti_rdi_${index}`}>
                                                    <Label className={`rdo_btn ${noOfLanguages < 3 ? 'm-0' : ''} ${defaultValue === langValue ? 'active' : ''}`} htmlFor={`lang_rdo_${index}`}>
                                                        {displayLabel}
                                                    </Label>
                                                    <Input
                                                        type="radio"
                                                        className={`custom-control-input`}
                                                        name={name}
                                                        id={`lang_rdo_${index}`}
                                                        value={JSON.stringify(langItem)}
                                                        disabled={isDisabled}
                                                        required={required}
                                                        checked={defaultValue === langValue ? 'checked' : ''}
                                                        onBlur={onBlurURL !== '' ? (e) => this.handleOnBlurEvent(e) : () => ({})}
                                                        onFocus={onFocusURL !== '' ? (e) => this.handleOnFocusEvent(e) : () => ({})}
                                                        onChange={isDisabled ? () => ({}) : ((e) => this.handleOnChangeEvent(e))}
                                                    />
                                                </div>
                                            )
                                        })}
                                    </div>
                                    {(errorMsg && labelString !== 'right') && <div className="validation_error">{errorMsg}</div>}
                                </div>
                                {labelTitle !== '' && <Label className={`control-label ${classLabel}${type === 'radio' ? ' lbl_rdo' : ''}`} align={lableAlign}>{labelTitle}{required && <span className="text-danger">*</span>}</Label>}
                                {(errorMsg && labelString === 'right') && <div className="validation_error col-12">{errorMsg}</div>}
                            </Fragment>
                            :
                            <Fragment>
                                {labelTitle !== '' && <Label className={`control-label ${classLabel}${type === 'radio' ? ' lbl_rdo' : ''}`} align={lableAlign}>{labelTitle}{required && <span className="text-danger">*</span>}</Label>}
                                <div className={`${classInput} ${className}${errorMsg ? ' is_err' : ''}`}>
                                    {/* <DynamicLanguageComponent props={this.props} state={this.state} languages={languages} handleOnChangeEvent={this.handleOnChangeEvent()} /> */}
                                    <div className={`cstm_icn_area show_btn row`}>
                                        {languages && languages.map((langItem, index) => {
                                            const { name: displayLabel = '', locale: langValue = '', icon = '', languageId = '' } = langItem;
                                            return (
                                                <div className={`col-6 rdo_btn_area ${lenghtClass}`} key={`mlti_rdi_${index}`}>
                                                    <Label className={`rdo_btn ${noOfLanguages < 3 ? 'm-0' : ''} ${defaultValue === langValue ? 'active' : ''}`} htmlFor={`lang_rdo_${index}`}>
                                                        {displayLabel}
                                                    </Label>
                                                    <Input
                                                        type="radio"
                                                        className={`custom-control-input`}
                                                        name={name}
                                                        id={`lang_rdo_${index}`}
                                                        value={JSON.stringify(langItem)}
                                                        disabled={isDisabled}
                                                        required={required}
                                                        checked={defaultValue === langValue ? 'checked' : ''}
                                                        onBlur={onBlurURL !== '' ? (e) => this.handleOnBlurEvent(e) : () => ({})}
                                                        onFocus={onFocusURL !== '' ? (e) => this.handleOnFocusEvent(e) : () => ({})}
                                                        onChange={isDisabled ? () => ({}) : ((e) => this.handleOnChangeEvent(e))}
                                                    />
                                                </div>
                                            )
                                        })}
                                    </div>
                                    {(errorMsg && labelString !== 'left') && <div className="validation_error">{errorMsg}</div>}
                                </div>
                                {(errorMsg && labelString === 'left') && <div className="validation_error col-12">{errorMsg}</div>}
                            </Fragment>
                    }
                </FormGroup>
            </Fragment>
        );
    }
}

export default LanguageProvider;
 /* End LanguageProvider component */